@@ -2,8 +2,6 @@ import base64
 import mimetypes
 from pathlib import Path
 
-from ..logger import logger
-
 
 def image_file_to_base64(file_path: Path) -> str:
     image_mime = mimetypes.guess_type(file_path, strict=True)[0]
@@ -11,7 +9,6 @@ def image_file_to_base64(file_path: Path) -> str:
     with open(file_path, "rb") as image_file:
         image_base64: bytes = base64.b64encode(image_file.read())
     result = prefix + image_base64.decode("UTF-8")
-    logger.debug(f"{result=}")
     return result
 
 
